#ifndef __APPLET_H__
#define __APPLET_H__

#include "gnomeicu.h"
#include "gtkfunc.h"
#include <gnome.h>
#include <gdk_imlib.h>
#include <applet-widget.h>

#include "common.h"

extern GtkWidget *darea;
extern gboolean have_read_config;
extern PanelOrientType orient;
extern int gnomeicu_size;

void make_applet( int argc, char *argv[], struct poptOption arguments[] );
void applet_update( DWORD status, GdkPixmap *flash );
void applet_clicked_cb( GtkWidget *widget, GdkEventButton *ev, gpointer data );
gboolean applet_hide_main( GtkWidget *widget, gpointer data );
void applet_remove( void );
void place_widgets( void );
void about( GtkWidget *widget, gpointer data );

#endif /* __APPLET_H__ */
